@@ -126,6 +126,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.core
@@ -159,6 +161,10 @@ class ApplicationProps:
                 description="description for my application"
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ApplicationProps.__init__)
+            check_type(argname="argument application_name", value=application_name, expected_type=type_hints["application_name"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
         self._values: typing.Dict[str, typing.Any] = {
             "application_name": application_name,
         }
@@ -241,6 +247,11 @@ class AttributeGroupProps:
                 }
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AttributeGroupProps.__init__)
+            check_type(argname="argument attribute_group_name", value=attribute_group_name, expected_type=type_hints["attribute_group_name"])
+            check_type(argname="argument attributes", value=attributes, expected_type=type_hints["attributes"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
         self._values: typing.Dict[str, typing.Any] = {
             "attribute_group_name": attribute_group_name,
             "attributes": attributes,
@@ -341,6 +352,10 @@ class CfnApplication(
         :param description: The description of the application.
         :param tags: Key-value pairs you can use to associate with the application.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnApplication.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnApplicationProps(name=name, description=description, tags=tags)
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -351,6 +366,9 @@ class CfnApplication(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnApplication.inspect)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -361,6 +379,9 @@ class CfnApplication(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnApplication._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
     @jsii.python.classproperty # type: ignore[misc]
@@ -414,6 +435,9 @@ class CfnApplication(
 
     @name.setter
     def name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnApplication, "name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
     @builtins.property # type: ignore[misc]
@@ -427,6 +451,9 @@ class CfnApplication(
 
     @description.setter
     def description(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnApplication, "description").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
 
@@ -468,6 +495,11 @@ class CfnApplicationProps:
                 }
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnApplicationProps.__init__)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
         }
@@ -571,6 +603,10 @@ class CfnAttributeGroup(
         :param description: The description of the attribute group that the user provides.
         :param tags: Key-value pairs you can use to associate with the attribute group.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnAttributeGroup.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnAttributeGroupProps(
             attributes=attributes, name=name, description=description, tags=tags
         )
@@ -583,6 +619,9 @@ class CfnAttributeGroup(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnAttributeGroup.inspect)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -593,6 +632,9 @@ class CfnAttributeGroup(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnAttributeGroup._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
     @jsii.python.classproperty # type: ignore[misc]
@@ -644,6 +686,9 @@ class CfnAttributeGroup(
 
     @attributes.setter
     def attributes(self, value: typing.Any) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnAttributeGroup, "attributes").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "attributes", value)
 
     @builtins.property # type: ignore[misc]
@@ -657,6 +702,9 @@ class CfnAttributeGroup(
 
     @name.setter
     def name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnAttributeGroup, "name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
     @builtins.property # type: ignore[misc]
@@ -670,6 +718,9 @@ class CfnAttributeGroup(
 
     @description.setter
     def description(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnAttributeGroup, "description").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
 
@@ -714,6 +765,10 @@ class CfnAttributeGroupAssociation(
         :param application: The name or ID of the application.
         :param attribute_group: The name or ID of the attribute group that holds the attributes to describe the application.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnAttributeGroupAssociation.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnAttributeGroupAssociationProps(
             application=application, attribute_group=attribute_group
         )
@@ -726,6 +781,9 @@ class CfnAttributeGroupAssociation(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnAttributeGroupAssociation.inspect)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -736,6 +794,9 @@ class CfnAttributeGroupAssociation(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnAttributeGroupAssociation._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
     @jsii.python.classproperty # type: ignore[misc]
@@ -785,6 +846,9 @@ class CfnAttributeGroupAssociation(
 
     @application.setter
     def application(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnAttributeGroupAssociation, "application").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "application", value)
 
     @builtins.property # type: ignore[misc]
@@ -798,6 +862,9 @@ class CfnAttributeGroupAssociation(
 
     @attribute_group.setter
     def attribute_group(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnAttributeGroupAssociation, "attribute_group").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "attributeGroup", value)
 
 
@@ -832,6 +899,10 @@ class CfnAttributeGroupAssociationProps:
                 attribute_group="attributeGroup"
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnAttributeGroupAssociationProps.__init__)
+            check_type(argname="argument application", value=application, expected_type=type_hints["application"])
+            check_type(argname="argument attribute_group", value=attribute_group, expected_type=type_hints["attribute_group"])
         self._values: typing.Dict[str, typing.Any] = {
             "application": application,
             "attribute_group": attribute_group,
@@ -917,6 +988,12 @@ class CfnAttributeGroupProps:
                 }
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnAttributeGroupProps.__init__)
+            check_type(argname="argument attributes", value=attributes, expected_type=type_hints["attributes"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
         self._values: typing.Dict[str, typing.Any] = {
             "attributes": attributes,
             "name": name,
@@ -1020,6 +1097,10 @@ class CfnResourceAssociation(
         :param resource: The name or ID of the resource of which the application will be associated.
         :param resource_type: The type of resource of which the application will be associated. Possible values: CFN_STACK.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnResourceAssociation.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnResourceAssociationProps(
             application=application, resource=resource, resource_type=resource_type
         )
@@ -1032,6 +1113,9 @@ class CfnResourceAssociation(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnResourceAssociation.inspect)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -1042,6 +1126,9 @@ class CfnResourceAssociation(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnResourceAssociation._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
     @jsii.python.classproperty # type: ignore[misc]
@@ -1091,6 +1178,9 @@ class CfnResourceAssociation(
 
     @application.setter
     def application(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnResourceAssociation, "application").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "application", value)
 
     @builtins.property # type: ignore[misc]
@@ -1104,6 +1194,9 @@ class CfnResourceAssociation(
 
     @resource.setter
     def resource(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnResourceAssociation, "resource").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resource", value)
 
     @builtins.property # type: ignore[misc]
@@ -1119,6 +1212,9 @@ class CfnResourceAssociation(
 
     @resource_type.setter
     def resource_type(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnResourceAssociation, "resource_type").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resourceType", value)
 
 
@@ -1160,6 +1256,11 @@ class CfnResourceAssociationProps:
                 resource_type="resourceType"
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnResourceAssociationProps.__init__)
+            check_type(argname="argument application", value=application, expected_type=type_hints["application"])
+            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
+            check_type(argname="argument resource_type", value=resource_type, expected_type=type_hints["resource_type"])
         self._values: typing.Dict[str, typing.Any] = {
             "application": application,
             "resource": resource,
@@ -1296,6 +1397,9 @@ class _IApplicationProxy(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IApplication.associate_attribute_group)
+            check_type(argname="argument attribute_group", value=attribute_group, expected_type=type_hints["attribute_group"])
         return typing.cast(None, jsii.invoke(self, "associateAttributeGroup", [attribute_group]))
 
     @jsii.member(jsii_name="associateStack")
@@ -1306,6 +1410,9 @@ class _IApplicationProxy(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IApplication.associate_stack)
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(None, jsii.invoke(self, "associateStack", [stack]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -1409,6 +1516,10 @@ class Application(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Application.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApplicationProps(
             application_name=application_name, description=description
         )
@@ -1431,6 +1542,11 @@ class Application(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Application.from_application_arn)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument application_arn", value=application_arn, expected_type=type_hints["application_arn"])
         return typing.cast(IApplication, jsii.sinvoke(cls, "fromApplicationArn", [scope, id, application_arn]))
 
     @jsii.member(jsii_name="associateAttributeGroup")
@@ -1441,6 +1557,9 @@ class Application(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Application.associate_attribute_group)
+            check_type(argname="argument attribute_group", value=attribute_group, expected_type=type_hints["attribute_group"])
         return typing.cast(None, jsii.invoke(self, "associateAttributeGroup", [attribute_group]))
 
     @jsii.member(jsii_name="associateStack")
@@ -1453,6 +1572,9 @@ class Application(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Application.associate_stack)
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(None, jsii.invoke(self, "associateStack", [stack]))
 
     @jsii.member(jsii_name="generateUniqueHash")
@@ -1463,6 +1585,9 @@ class Application(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Application._generate_unique_hash)
+            check_type(argname="argument resource_address", value=resource_address, expected_type=type_hints["resource_address"])
         return typing.cast(builtins.str, jsii.invoke(self, "generateUniqueHash", [resource_address]))
 
     @builtins.property # type: ignore[misc]
@@ -1531,6 +1656,10 @@ class AttributeGroup(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AttributeGroup.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AttributeGroupProps(
             attribute_group_name=attribute_group_name,
             attributes=attributes,
@@ -1555,6 +1684,11 @@ class AttributeGroup(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(AttributeGroup.from_attribute_group_arn)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument attribute_group_arn", value=attribute_group_arn, expected_type=type_hints["attribute_group_arn"])
         return typing.cast(IAttributeGroup, jsii.sinvoke(cls, "fromAttributeGroupArn", [scope, id, attribute_group_arn]))
 
     @builtins.property # type: ignore[misc]
